@@ -54,10 +54,11 @@ void GeoTIFFMap::draw(QPainter *painter, const QRectF &rect, Flags flags)
 }
 
 void GeoTIFFMap::load(const Projection &in, const Projection &out,
-  qreal deviceRatio, bool hidpi, int layer)
+  qreal deviceRatio, bool hidpi, int style, int layer)
 {
 	Q_UNUSED(in);
 	Q_UNUSED(out);
+	Q_UNUSED(style);
 	Q_UNUSED(layer);
 
 	_ratio = hidpi ? deviceRatio : 1.0;
