@@ -5,7 +5,7 @@
 #include "common/range.h"
 #include "common/rectc.h"
 #include "common/kv.h"
-#include "common/downloader.h"
+#include "downloader.h"
 #include "coordinatesystem.h"
 
 class Map;
@@ -43,7 +43,8 @@ private:
 		QList<HTTPHeader> headers;
 		qreal tileRatio;
 		int tileSize;
-		bool scalable;
+		bool mvt;
+		QStringList layers;
 
 		Config();
 	};
